@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::DAGOLDEN;
-our $VERSION = '0.041'; # VERSION
+our $VERSION = '0.042'; # VERSION
 
 # Dependencies
 use autodie 2.00;
@@ -20,6 +20,7 @@ use Dist::Zilla::Plugin::CheckChangesHasContent ();
 use Dist::Zilla::Plugin::CheckExtraTests        ();
 use Dist::Zilla::Plugin::CheckMetaResources 0.001  ();
 use Dist::Zilla::Plugin::CheckPrereqsIndexed 0.002 ();
+use Dist::Zilla::Plugin::ContributorsFromGit 0.004 ();
 use Dist::Zilla::Plugin::CopyFilesFromBuild ();
 use Dist::Zilla::Plugin::Git::NextVersion   ();
 use Dist::Zilla::Plugin::InsertCopyright 0.001 ();
@@ -172,6 +173,13 @@ sub configure {
             : [ 'Git::NextVersion' => { version_regexp => $self->version_regexp } ]
         ),
 
+        # contributors
+        (
+            $self->no_git
+            ? ()
+            : 'ContributorsFromGit'
+        ),
+
         # gather and prune
         (
             $self->no_git
@@ -341,7 +349,7 @@ Dist::Zilla::PluginBundle::DAGOLDEN - Dist::Zilla configuration the way DAGOLDEN
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 SYNOPSIS
 
@@ -357,6 +365,9 @@ following dist.ini:
    [Git::NextVersion]  ; get version from last release tag
    version_regexp = ^release-(.+)$
  
+   ; collect contributors list
+   [ContributorsFromGit]
+ 
    ; choose files to include
    [Git::GatherDir]         ; everything from git ls-files
    exclude_filename = README.pod   ; skip this generated file
@@ -595,6 +606,24 @@ L<https://github.com/dagolden/dist-zilla-pluginbundle-dagolden>
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Christian Walde <walde.christian@googlemail.com>
+
+=item *
+
+Eric Johnson <eric.git@iijo.org>
+
+=item *
+
+Philippe Bruhat (BooK) <book@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
